@@ -62,6 +62,10 @@ void	config(int argc, char **argv)
                         {
                                 AutoEntry = atoi(pnt);
                         }
+                        else if (!memcmp (buff, "REPEATER_AUTO_ENTRY", 19))
+                        {
+                                RepAutoEntry = atoi(pnt);
+                        }
                         else if (!memcmp (buff, "TRUST_DB_DOMAIN_NAME", 20))
                         {
                                 memset (TrustDbDomainName, 0x00, 128);
