@@ -1,7 +1,7 @@
 DROP TABLE call_sign;
 
 CREATE TABLE call_sign (
-	call		CHAR(8) NOT NULL UNIQUE,
+	call		CHAR(8) PRIMARY KEY,
 	rep_call	CHAR(8) NOT NULL,
 	u_time		TIMESTAMP,
 	entry_type	CHAR
@@ -10,7 +10,7 @@ CREATE TABLE call_sign (
 DROP TABLE repeater;
 
 CREATE TABLE repeater (
-	rep_call	CHAR(8) NOT NULL UNIQUE,
+	rep_call	CHAR(8) PRIMARY KEY,
 	trust_name	CHAR(16),
 	u_time		TIMESTAMP
 );
